import type { GrammarToken, ParserAction } from "./types";
/**
 * Creates an `ArrayBuffer` stored token. This is effectively a highly
 * efficient representation of a {@link GrammarToken}.
 *
 * Returns an ArrayBuffer that is, in order:
 *
 * - The token ID, which is a uint8
 * - The token from position, which is a uint32
 * - The token length, which is a uint16
 * - A repeating list of parser actions
 *
 * Parser actions are:
 *
 * - Action type, which is a uint8 (0 is OPEN, 1 is CLOSE)
 * - Node id, which is a uint8
 */
export declare function create(id: number | null, from: number, to: number, open?: ParserAction, close?: ParserAction): ArrayBuffer;
/**
 * Reads an `ArrayBuffer` token.
 *
 * @param token - The token to read.
 * @param offset - The offset to add to the token's position.
 */
export declare function read(token: ArrayBuffer, offset?: number): GrammarToken;
/**
 * Returns true if the given token has any parser actions.
 *
 * @param token - The token to check.
 */
export declare function hasActions(token: ArrayBuffer): boolean;
/**
 * Reads the actions from an `ArrayBuffer` token.
 *
 * @param token - The token to read.
 */
export declare function actions(token: ArrayBuffer): {
    open: ParserAction | undefined;
    close: ParserAction | undefined;
};
